summaryrefslogtreecommitdiff
path: root/gamut/gamut.h
diff options
context:
space:
mode:
authorJörg Frings-Fürst <debian@jff-webhosting.net>2016-10-02 19:24:58 +0200
committerJörg Frings-Fürst <debian@jff-webhosting.net>2016-10-02 19:24:58 +0200
commit3db384424bd7398ffbb7a355cab8f15f3add009f (patch)
tree4536961c62454aca3ac87ee88229e4d20c0d44fa /gamut/gamut.h
parentd479dd1aab1c1cb907932c6595b0ef33523fc797 (diff)
New upstream version 1.9.1+repackupstream/1.9.1+repack
Diffstat (limited to 'gamut/gamut.h')
-rw-r--r--gamut/gamut.h14
1 files changed, 11 insertions, 3 deletions
diff --git a/gamut/gamut.h b/gamut/gamut.h
index e70d898..e74f942 100644
--- a/gamut/gamut.h
+++ b/gamut/gamut.h
@@ -249,7 +249,7 @@ struct _gamut {
double xvra; /* Extra vertex ratio - set/used by nssverts() */
int ssnverts; /* total ss verticies - set/used by nssverts() */
int ssvertn; /* Number of verts created for current triangle */
- sobol *ss; /* Sibol ss generator currently being used */
+ sobol *ss; /* Sobol ss generator currently being used */
gtri *nexttri; /* Context for getnexttri() */
@@ -315,14 +315,22 @@ struct _gamut {
/* Initialise this gamut with the intersection of the */
/* the two given gamuts. */
+ int (*exp_cyl)(struct _gamut *s, struct _gamut *s1, double ratio);
+ /* Initialise this gamut with the source gamut */
+ /* expanded cylindrically around the nautral axis by */
+ /* the given ratio. */
+
int (*nexpintersect)(struct _gamut *s, struct _gamut *s1, struct _gamut *s2);
/* Return s1 expanded with neutral axis points */
/* and then intersected with s2. */
int (*expdstbysrcmdst)(struct _gamut *s,
struct _gamut *dst, struct _gamut *sc, struct _gamut *dc,
void (*cvect)(void *cntx, double *p2, double *p1), void *cntx);
/* Expand dst by ((dc - sc) > 0) */
+ /* Initialise this gamut with the image/destination gamut sc */
+ /* expanded by the amount that dest (dc) colorspace is outside */
+ /* the source colorspace gamut. */
double (*radial)(struct _gamut *s, double out[3], double in[3]);
/* return point on surface in same radial direction. */
@@ -315,14 +315,22 @@ struct _gamut {
int (*nexpintersect)(struct _gamut *s, struct _gamut *s1, struct _gamut *s2);
- /* Return s1 expanded with neutral axis points */
- /* and then intersected with s2. */
+ /* Initialise this gamut with neutral axis points from sa, */
+ /* and then intersected with sb. */
int (*expdstbysrcmdst)(struct _gamut *s,
struct _gamut *dst, struct _gamut *sc, struct _gamut *dc,